/*
 * A simple clock.
 *
 * Displays the date/time in one of 4 formats:
 * - 12 Hour Time - TIME('C')
 * - 24 Hour Time - TIME('N')
 * - Unix Time    - TIME('T')
 * - Date         - DATE('N')
 *
 * The format of the display can be changed by using the
 * left and right arrows
 *
 * Change the font size by using the up and down arrows
 */
Trace o
Call Rxfuncadd 'TkLoadFuncs','rexxtk','TkLoadFuncs'
If TkLoadFuncs() \= 0 Then exit

Numeric Digits 10

Parse Source os .
If os = 'UNIX' Then 
   Do
      ini = Value( 'HOME', , 'ENVIRONMENT')'/.tkclock'
   End
Else
   Do
      ini = 'c:\.tkclock'
   End

min_font_size = 10
max_font_size = 120

If Stream( ini, 'C', 'QUERY EXISTS' ) \= '' Then
   Do
      Call Stream ini, 'C', 'OPEN READ'
      conf = Linein( ini )
      Parse Var conf 1 clock_type 2 now_font_size
      Call Stream ini, 'C', 'CLOSE'
   End
Else
   Do
      clock_type = 2
      now_font_size = 16
   End

/* create the main window */
Call CreateMain

Do Forever
   Interpret 'call' TkWait()
End
Call TkDropFuncs
return 0

CreateMain:
Call TkWm 'title', '.', 'Rexx/Tk Clock'

clock = TkLabel( '.clock', '-text', Time('C'), '-font', 'Helvetica-Bold' now_font_size )
Call TkPack clock

/* create the clock display */
Call DisplayClock

Call TkBind 'all', '<Left>', '*ChangeDisplayType -1'
Call TkBind 'all', '<Right>', '*ChangeDisplayType 1'
Call TkBind 'all', '<Down>', '*ChangeFontSize -2'
Call TkBind 'all', '<Up>', '*ChangeFontSize 2'

Return

DisplayClock:
Select
   When clock_type = 1 Then str = Time('C')
   When clock_type = 2 Then str = Time('N')
   When clock_type = 3 Then str = Time('T')
   When clock_type = 4 Then str = Date('N')
   Otherwise Nop
End
Call TkConfig clock, '-text', str, '-font', 'Helvetica-Bold' now_font_size

Call TkTcl 'after 100 setRexxtk DisplayClock'
Return

ChangeDisplayType:
Parse Arg inc
new_clock_type = clock_type + inc
Select
   When new_clock_type = 0 Then clock_type = 4
   When new_clock_type = 5 Then clock_type = 1
   Otherwise clock_type = new_clock_type
End
Call DisplayClock
Call UpdateIni
Return

ChangeFontSize:
Parse Arg inc
new_font_size = now_font_size + inc
Select
   When new_font_size < min_font_size Then now_font_size = max_font_size
   When new_font_size > max_font_size Then now_font_size = min_font_size
   Otherwise now_font_size = new_font_size
End
Call DisplayClock
Call UpdateIni
Return

Updateini:
Call Stream ini, 'C', 'OPEN WRITE REPLACE'
Call Lineout ini, clock_type||now_font_size
Call Stream ini, 'C', 'CLOSE'
Return

quit:
exit:
Call TkDropFuncs
Exit 0
